#####################
PyHwloc Low Level API
#####################

This page provides the reference for the low level interface. This low level interface is
a direct mapping from the :doc:`hwloc C API </c>` to the Python environment. Function and
enum names in the Python binding omit the ``hwloc_`` prefix for brevity.

.. contents::
    :backlinks: none
    :local:

.. automodule:: pyhwloc.hwloc.bitmap
  :members:

.. automodule:: pyhwloc.hwloc.core
  :members:

.. automodule:: pyhwloc.hwloc.cudadr
  :members:

.. automodule:: pyhwloc.hwloc.cudart
  :members:

.. automodule:: pyhwloc.hwloc.linux
  :members:

.. automodule:: pyhwloc.hwloc.nvml
  :members:

.. automodule:: pyhwloc.hwloc.sched
  :members:

.. automodule:: pyhwloc.hwloc.windows
  :members: